Versions
========

0.2.0 (2016-07-05)
------------------

- Change module layout to plan for new hardware implementations
- Add documentation tree
- More tests 

0.1.2 (2016-07-05)
------------------

- Fixed serial initialization issue

0.1.1 (2016-07-04)
------------------

- CI/automation changes

0.1.0 (2016-07-04)
------------------

- Initial Release
- Basic ET-312 functionality

